==> fcitx-configtool_0.4.4.orig.tar.xz: fcitx-configtool-0.4.4/gtk3/common.c <==
/***************************************************************************
 *   Copyright (C) 2010~2012 by CSSlayer                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************/

#include "common.h"

FcitxAddon* find_addon_by_name(UT_array* array, gchar* name)
{
    FcitxAddon* addon = NULL;
    for (addon = (FcitxAddon *) utarray_front(array);
         addon != NULL;
         addon = (FcitxAddon *) utarray_next(array, addon)) {
        if (strcmp(addon->name, name) == 0)
            break;
    }
    return addon;
}

==> fcitx-configtool_0.4.10.orig.tar.xz: fcitx-configtool-0.4.10/gtk3/common.c <==
/***************************************************************************
 *   Copyright (C) 2010~2012 by CSSlayer                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************/

#include "common.h"

FcitxAddon* find_addon_by_name(UT_array* array, const gchar* name)
{
    FcitxAddon* addon = NULL;
    for (addon = (FcitxAddon *) utarray_front(array);
         addon != NULL;
         addon = (FcitxAddon *) utarray_next(array, addon)) {
        if (strcmp(addon->name, name) == 0)
            break;
    }
    return addon;
}
